@@ -159,6 +159,7 @@ class CopyToTable(luigi.task.MixinNaiveBulkComplete, _MetadataColumnsMixin, luig
         * `password`,
         * `table`
         * `columns`
+        * `port`
     """
 
     @abc.abstractproperty
@@ -181,6 +182,10 @@ class CopyToTable(luigi.task.MixinNaiveBulkComplete, _MetadataColumnsMixin, luig
     def table(self):
         return None
 
+    @property
+    def port(self):
+        return None
+
     # specify the columns that are to be inserted (same as are returned by columns)
     # overload this in subclasses with the either column names of columns to import:
     # e.g. ['id', 'username', 'inserted']
